;+
; NAME:
;	DATATYPE
; PURPOSE:
;	Returns data type as a string.
;	Makes it easier to do data type dependent operations.
; CATEGORY:
;	Utility.
; CALLING SEQUENCE:
;	Result = DATATYPE(VAR)
; INPUTS:
;	VAR = a variable.
; KEYWORD PAPRAMETER:
;	FULL: If present and non-zero then type is spelled out, else 3 chars.
; OUTPUTS:
;	Result = a string indicating the data type of VAR.
;	   Result is 3 char upper case: UND, BYT, INT, LON, FLO, DOU, COM,
;	   STR, STU unless FULL is set.
; PROCEDURE:
;	Uses SIZE.
; MODIFICATION HISTORY:
;	Written by R. Sterner, 24 Oct, 1985.
;	RES 29 June, 1988 --- added spelled out TYPE.
;	Johns Hopkins University Applied Physics Laboratory.
;	Ian Grant, HIA/NRCC, 11 Mar 1991: Converted to IDL2.
;	   Added Structure type.
;	IFG, 22 Dec 1992: Added ON_ERROR. Changed FLAG parameter to FULL
;	   keyword.
;-

FUNCTION DATATYPE, VAR, FULL=FULL

	ON_ERROR, 2
	S = SIZE(VAR)

	IF NOT KEYWORD_SET(FULL) THEN BEGIN
	  CASE S(S(0)+1) OF
   0:	    TYP = 'UND'
   1:       TYP = 'BYT'
   2:       TYP = 'INT'
   3:       TYP = 'LON'
   4:       TYP = 'FLO'
   5:       TYP = 'DOU'
   6:       TYP = 'COM'
   7:       TYP = 'STR'
   8:       TYP = 'STU'
ELSE:       PRINT,'Error in DATATYPE'
	  ENDCASE
	ENDIF ELSE BEGIN
	  CASE S(S(0)+1) OF
   0:	    TYP = 'Undefined'
   1:       TYP = 'Byte'
   2:       TYP = 'Integer'
   3:       TYP = 'Long'
   4:       TYP = 'Float'
   5:       TYP = 'Double'
   6:       TYP = 'Complex'
   7:       TYP = 'String'
   8:       TYP = 'Structure'
ELSE:       PRINT,'Error in DATATYPE'
	  ENDCASE
	ENDELSE

	RETURN, TYP

	END
