      PRO DOY_MMDD, year, doy, mon, day, doy=bck, day_month=fwd
;+
; NAME:		DOY_MMDD
;
; PURPOSE:
;        To convert the Day of year to month and day.
;
; CATEGORY:
;        Utility.
;
; CALLING SEQUENCE:	DOY_MMDD, year, doy, mon, day [, /DOY] [, /DAY_MONTH]
;        
; INPUTS:	year  - 4 digit year
;          	doy   - day number
;
; OPTIONAL INPUTS: 
;		/DOY - the day of year is requested from month and day (def)
;		/DAY_MONTH  - day and month are requested from day of year
;
; OUTPUTS:	mon   - month number
;       	day   - day of the month
;
; PROCEDURE:
;        None.
;
; MODIFICATION HISTORY:
;   8-JUL-1993  D.F. Tanguay 	- Creation date.
;   4-OCT-1993  E.Sidaway + D.F. Tanguay - Corrected d_in_mth(1)
;  12-OCT-1994  D.F. Tanguay	- Added opposite direction
;-

	d_in_mth = INTARR(12)
	d_in_mth = [31,28,31,30,31,30,31,31,30,31,30,31]
	leap = 0  ; assume it is not a leap year
;
; Is it a leap year?
	IF (400*(year/400) EQ year) Then leap = 1 $
	Else If (4*(year/4) eq year) and (100*(year/100) ne year) Then $
	 leap = 1 $
	Else leap = 0
;
	d_in_mth(1)=d_in_mth(1)+leap

	If keyword_set(bck) Then Begin
	  If ((mon gt 12) or (mon lt 1)) Then Begin
	    Print,'DOY_MMDD: error in month specified'
	    doy = -1
	    Return
	  EndIf

	  If ((day gt d_in_mth(mon - 1)) or day lt 1) Then Begin
	    Print,'DOY_MMDD: error in day specified'
	    doy = -1
	    Return
	  EndIf

	  doy = 0
	  For i = 0,mon-2 Do doy = doy + d_in_mth(i)
	  doy = doy + day

	EndIf Else Begin

	  If ((doy gt 365+leap) or (doy lt 1))Then Begin
	    Print,'DOY_MMDD: error in day of year specified'
	    day = -1
	    mon = -1
	    Return
	  EndIf

	  tmp = doy
	  mon = 0
	  While (tmp gt 0) Do Begin
	    day = tmp
	    tmp  = tmp - d_in_mth(mon)
	    mon = mon + 1
	  EndWhile

	EndElse
      RETURN
      END
