PRO xyouts_sphere,lat_data,long_data,label,$
    altitude=alt,radius=rad,size=sz,$
    alignment=alm,orientation=orient,color=clr,thick=thk,width=width
;+
; NAME:
;    XYOUTS_SPHERE
; PURPOSE:
;    To write text on a sphere or globe. The sphere must first be gererated
;    using PLOT_SPHERE.
; CATEGORY:
;    plotting
; CALLING SEQUENCE:
;    XYOUTS_SPHERE,LAT_DATA,LONG_DATA,LABEL
;
;    XYOUTS_SPHERE,LAT_DATA,LONG_DATA,LABEL [,ALTITUDE=array] 
;          [,RADIUS=value]]  [,SIZE=value]
; INPUTS:
;    LAT_DATA  real scalar  - latitude value of the text to be plotted
;                            on the sphere 
;    LONG_DATA real scalar  - longitude value of the text to be plotted
;                            on the sphere
;    LABEL string  - text to be drawn at specified point
;
; OPTIONAL INPUT PARAMETERS: 
;    None
; KEYWORD PARAMETERS:
;    ALTITUDE - Scalar containing the relative altitude above the surface
;               of the sphere. This value should be scaled relative to
;               the earth radius. (Ex 1.0 = 1 earth radius above surface)
;    RADIUS - Used to change the relative value of the earth radius.
;             Default=1.
;   SIZE - controls the size of the characters plotted, default = 1.0
;
; OUTPUTS:
;    none
; OPTIONAL OUTPUT PARAMETERS:
;    None
; COMMON BLOCKS:
;    PLOT_SPHR,LATV,LONGV
;      LATV  real value  - latitude coresponding to the center of the
;                          view of the sphere
;      LONGV real value  - longitude coresponding to the center of the
;                          view of the sphere
; SIDE EFFECTS: None
; RESTRICTIONS: None
; PROCEDURE:
;    The sphere must first be defined by a call to PLOT_SPHERE.
;    Ex. Plot_sphere,lat,long
; MODIFICATION HISTORY:
;    Created in IDL 2 - Jan. 1991 - J.D. Trickey
;-
;
common plot_sphr,lat_val,long_val
;
if keyword_set(sz) then size=sz else size=1.0
if keyword_set(alm) then align_val=alm else align_val=0.0
if keyword_set(orient) then orient_val=orient else orient_val=0.0
if n_elements(width) ne 0 then width_val=width else width_val=0.0
if n_elements(clr) ne 0 then begin
     color_old=!p.color
     !p.color=clr
endif
if n_elements(thk) ne 0 then begin
     thick_old=!p.thick
     !p.thick=thk
endif
;
if keyword_set(rad) then earth_rad=rad else earth_rad=1.
;
thet=(90-lat_val)/!radeg 
phet=long_val/!radeg
rot1=[[cos(phet),sin(phet),0],[-sin(phet),cos(phet),0],[0,0,1.0]]
rot2=[[cos(thet),0,-sin(thet)],[0,1.0,0],[sin(thet),0,cos(thet)]]
if n_elements(alt) ne 0 then begin
    diameter=alt+earth_rad
endif else diameter=earth_rad
;
    lon=long_data
    if (lon gt 180.0) then lon=lon-360.0 
    if (lon lt -180.) then lon=lon+360.0
      the=lat_data  
      phi=lon
      z=diameter             
      if ((abs(the) le 90.)and (abs(phi) le 360.)) then begin 
          th=(90-the)/!radeg 
          ph=lon/!radeg            
          pos=[sin(th)*cos(ph),sin(th)*sin(ph),cos(th)]*z
          pn=pos#rot1#rot2                                 
          nx=-pn(0) 
          ny=pn(1) 
          nz=pn(2)         
      endif else begin                                     
          nx=-10  
          ny=-10 
          nz=-1 
      endelse                                              
    nr=sqrt(nx*nx+ny*ny)
    if (nz lt 0.0 and nr lt 1.0) then return
    xyouts,ny,nx,label,size=size,align=align_val,orient=orient_val,$
                       width=width_val
;
if n_elements(clr) ne 0 then begin
     !p.color=color_old
endif
if n_elements(thk) ne 0 then begin
     !p.thick=thick_old
endif
if n_elements(width) ne 0 then begin
     width=width_val
endif
;
RETURN
END
