PRO TIMESCALE,STIME,ETIME,VERTICAL=VERT,TITLE=TIMELAB,NOLABELS=NOLAB,$
     TOP=TOP,TIC_FACTOR=TICFAC,NODAYLABELS=NODAYLAB, CHARSIZE = CHARSIZE
;stop
;
;+
; NAME:   TIMESCALE
; PURPOSE:
;         This routine is designed to make tick marks and labels for
;         a time axis. The time axis is the X axis and is defined in terms
;         of seconds.
; CATEGORY:
;          plotting, axes, time
; CALLING SEQUENCE:
;           TIMESCALE,STARTTIME,ENDTIME  [,TITLE=string] [,/TOP]
;                                        [,/VERTICAL] [,/NOLABELS]
;                                        [,TIC_FACTOR=number] [/NODAYLABELS]
; INPUTS:
;     STARTTIME - time value in seconds for left hand side of plot (lowest
;                 value on time axis)
;     ENDTIME -   time value in seconds for right hand side of plot (highest
;                 value on time axis)
; OPTIONAL INPUT PARAMETERS:
;         none
; KEYWORD PARAMETERS:
;    TITLE -      set to string that is to be used as the title for the axis
;                 default = 'Time (UT)'
;    TOP   -      if set the axis will be plotted at the top of the plot as
;                 well as the bottom. if not set then bottom only is plotted
;    VERTICAL -   if set verical dotted lines are plotted corresponding to
;                 the major tick marks
;    NOLABELS -   if set the labeling of ticks will be suppressed
;    TIC_FACTOR - determines the size of the tick marks used. This number
;                 is mulplied by the ticksize to make the new tick ticksize.
;                 default=1
;    NODAYLABELS - don't use day number on axis labels
; OUTPUTS:
;    none
; OPTIONAL OUTPUT PARAMETERS:
;    none
; COMMON BLOCKS:
;    none
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
;    The routine can only be called after the first plot command
; MODIFICATION HISTORY:
;  Created by J. D. Trickey - 08-May-1991
;  Corrected problem when limits are not on even units.
;              - J.D. Trickey - 10-Jun-1991
;  Upgrade to IDL version 3.5 will not allow the position keyword in
;  the call to axis. - J.D.Trickey - 03-DEC-1993
;  TJH 94.06.17 Added keyword NODAYLABELS at suggestion of Ian Grant, UWO.
;               Use of this keyword cause axes to be labelled without day
;               number.
;  Fix problem of day number appearing when not needed. Also made sure
;  the labels are not being generated when they are not going to be used.
;  - J. D. Trickey
;	JWM April 2004 added keyword charsize
;-
;
;
Pos_save=!p.position
xticks=!x.ticks
xminor=!x.minor
xtitle=!x.title
minute=60
hour=3600
day=86400
spacing=[0.005,$
         0.01,0.02,0.05,$
         0.1,0.2,0.5,$
         1,2,5,10,30,$
         60,120,300, $
         600,900,1800,3600,7200, $
         10800,14400,21600,43200,86400,172800, $
         345600,691200,1382400]
;num_minor=[5,$
;           5,5,5,$
;           5,5,5,$
;           5,5,5,5,6,$
;           6,6,5,$
;           5,6,6,6,6,$
;           6,4,6,6,6,4,$
;           4,4,4]

;      +-------------------------------------------------------------------+
;      |Following alterations at behest of Ian Grant & John MacDougall     |
;      +-------------------------------------------------------------------+
num_minor=[5,$
           5,4,5,$
           5,4,5,$
           5,4,5,5,6,$
           6,6,5,$
           5,3,6,6,6,$
           6,4,6,6,6,4,$
           4,4,4]
declab=0
seclab=1
if keyword_set(ticfac) then tic_factor=ticfac else tic_factor=1
;
pos_arr=!p.position
max_ticks=long((!p.position(2)-!p.position(0))*10)
if (max_ticks eq 0) then begin
   max_ticks=long((!x.window(1)-!x.window(0))*10)
   pos_arr=[!x.window(0),!y.window(0),!x.window(1),!y.window(1)]
endif
if (max_ticks le 1) then max_ticks=long((!x.window(1)-!x.window(0))*50)
delta_t=etime-stime+1
;
num_ticks=1000
scale=-1
while num_ticks gt max_ticks do begin
    scale=scale+1
    num_ticks=long(delta_t/spacing(scale))
endwhile

if scale le 5 then declab=1
if scale ge 12 then seclab=0

;      +-------------------------------------------------------------------+
;      |Code modified here by HUGHES, at suggestion of GRANT to permit     |
;      |use if the keyword NODAYLABELS  17-JUN-1994                        |
;      +-------------------------------------------------------------------+
daylab=0                                        ; Moved by HUGHES 17-JUN-1994
if (not keyword_set(nodaylab)) and (not keyword_set(nolab)) then begin ; Added by HUGHES 17-JUN-1994
   if scale ge 21 then daylab=1
   if long(stime/day) ne long(etime/day) then daylab=1
endif
;
xtime=stime
xtime=long(xtime/spacing(scale))*spacing(scale)
while xtime lt stime do xtime=xtime+spacing(scale)
;
!x.minor=num_minor(scale)
!x.ticks=num_ticks
for i=0l,num_ticks do begin
   time=xtime+i*spacing(scale)
   if ((time ge stime) and (time le etime)) then begin  ; added 10-Jun-91
      !x.tickv(i)=float(time)
      if keyword_set(vert) then begin
         xx=[time,time]
         yy=[!y.crange(0),!y.crange(1)]
         oplot,xx,yy,linestyle=1
      endif
      if keyword_set(nolab) then begin
         !x.tickname(i)=' '
      endif else begin
         if (daylab) then begin
            day_str=strtrim(string(long(time/day)),2)+'/'
            if strlen(day_str) lt 3 then day_str='00'+day_str
            if strlen(day_str) lt 4 then day_str='0'+day_str
         endif else day_str=' '
         time=time MOD day
         hour_str=strtrim(string(long(time/hour)),2)+':'
         if strlen(hour_str) lt 3 then hour_str='0'+hour_str
         time=time MOD hour
         min_str=strtrim(string(long(time/minute)),2)
         if strlen(min_str) lt 2 then min_str='0'+min_str
         if (seclab) then begin
            time=time MOD minute
            sec_str=strtrim(string(long(time)),2)
            if strlen(sec_str) lt 2 then sec_str='0'+sec_str
            sec_str=':'+sec_str
         endif else sec_str=' '
         if (declab) then begin
            time=time MOD 1
            dec_str='.'+strtrim(string(long(time*100)),2)
         endif else dec_str=' '
         !x.tickname(i)=strtrim(day_str+hour_str+min_str+sec_str+dec_str,2)
      endelse
   endif else !x.ticks=!x.ticks-1           ; added 10-Jun-91
endfor
;
if !x.ticks lt 1 then !x.ticks=1
;
if not keyword_set(charsize) then charsize = 1.0
!p.ticklen=!p.ticklen*tic_factor
if keyword_set(timelab) then !x.title=timelab else $
   if keyword_set(nolab) then !x.title='' else !x.title='Time (UT)'
!p.position=pos_arr
axis,xaxis=0,charsize=0.8*charsize
; axis,xaxis=0,charsize=0.8,position=pos_arr
!x.title=''
if keyword_set(top) then begin
   for i=0l,num_ticks do begin
      !x.tickname=' '
   endfor
   !p.ticklen=-1*!p.ticklen
   axis,xaxis=1, charsize = charsize
;   axis,xaxis=1,position=pos_arr
   !p.ticklen=-1*!p.ticklen
endif
;
; reset system variables
;
!x.ticks=xticks
!x.minor=xminor
!x.title=xtitle
!p.ticklen=!p.ticklen/tic_factor
!p.position=pos_save
for i=0l,num_ticks do begin
   !x.tickv=0.0
   !x.tickname=''
endfor
;
return
end
