;NAME
;    CADI_PHASE_CAL
;
;PURPOSE
;		To plot receiver response for pairs of reciveres to check for phase errors
;   	similar to plot_sat c language program
; CALLING SEQUENCE:
;		CADI_PHASE_CAL, CADI_HT, heightrange
;		CADI_HT = input structure of type cadi as prepared by cadi_read_dir
;		heightrange = 2 element array giving minimum and maximum heights
; KEYWORD PARAMETERS
;		Colour = if set (ne 0) then plot in colour (not used by cadi widgets except to change
;		to plotting black on white if set.
; MODIFICATION HISTORY:
;		written: by JWM April 2004

pro cadi_phase_cal, cadi_ht, heightrange = heightrange, colour = colour


!p.multi = [0,2,2]
if keyword_set(colour) then begin
  !p.background = 255b
  !p.color = 0b
endif else begin
  !p.background = 0
  !p.color = 255b
endelse
erase

h = cadi_ht.header
d = cadi_ht.data

site = cadi_site(h.site, h.time)      ; For antenna order and polarity
nantennas = h.nantennas
if (nantennas eq 1) then begin
  print, 'only 1 receiver so cant do phase calibration'
  goto, exit1receiver
endif

if not keyword_set(heightrange) then heightrange = [0,510]
minht = fix(heightrange(0)/3)
maxht = fix(heightrange(1)/3)
selht = where((d.x.h ge minht)and(d.x.h le maxht))
d = d(selht)
;stop
nel = n_elements(d)
print, 'no elements = ',nel
r1mag = fltarr(nel)
r1phase = fltarr(nel)
r2mag = fltarr(nel)
r2phase = fltarr(nel)
r3mag = fltarr(nel)
r3phase = fltarr(nel)
r4mag = fltarr(nel)
r4phase = fltarr(nel)
for i = 0, nel-1 do begin
  rcvr1re = float(d(i).IQ(0,0))
  if rcvr1re gt 127 then rcvr1re = rcvr1re - 256
  rcvr1im = float(d(i).IQ(1,0))
  if rcvr1im gt 127 then rcvr1im = rcvr1im - 256
  r1mag(i) = sqrt(rcvr1re^2 + rcvr1im^2)
  r1phase(i) = !radeg*atan(rcvr1im,rcvr1re)
  if (r1phase(i) lt 0) then r1phase(i) = r1phase(i) + 360
  rcvr2re = float(d(i).IQ(0,1))
  if rcvr2re gt 127 then rcvr2re = rcvr2re - 256
  rcvr2im = float(d(i).IQ(1,1))
  if rcvr2im gt 127 then rcvr2im = rcvr2im - 256
  phasing = site.polarity(0)*site.polarity(1)
  rcvr2re = phasing*rcvr2re
  rcvr2im = phasing*rcvr2im
  r2mag(i) = sqrt(rcvr2re^2 + rcvr2im^2)
  r2phase(i) = !radeg*atan(rcvr2im,rcvr2re)
  if (r2phase(i) lt 0) then r2phase(i) = r2phase(i) + 360
  if (nantennas eq 4) then begin
  rcvr3re = float(d(i).IQ(0,2))
  if rcvr3re gt 127 then rcvr3re = rcvr3re - 256
  rcvr3im = float(d(i).IQ(1,2))
  if rcvr3im gt 127 then rcvr3im = rcvr3im - 256
  r3mag(i) = sqrt(rcvr3re^2 + rcvr3im^2)
  r3phase(i) = !radeg*atan(rcvr3im,rcvr3re)
  if (r3phase(i) lt 0) then r3phase(i) = r3phase(i) + 360
  rcvr4re = float(d(i).IQ(0,3))
  if rcvr4re gt 127 then rcvr4re = rcvr4re - 256
  rcvr4im = float(d(i).IQ(1,3))
  if rcvr4im gt 127 then rcvr4im = rcvr4im - 256
  phasing = site.polarity(2)*site.polarity(3)
  rcvr4re = phasing*rcvr4re
  rcvr4im = phasing*rcvr4im
  r4mag(i) = sqrt(rcvr4re^2 + rcvr4im^2)
  r4phase(i) = !radeg*atan(rcvr4im,rcvr4re)
  if (r4phase(i) lt 0) then r4phase(i) = r4phase(i) + 360
  endif ;4 antennas
endfor
print, 'doing phase plots'
;calculate phase correction from regression line
phaseok = where(abs(r2phase - r1phase) lt 90)
r1phasesel = r1phase(phaseok)		;avoid problems with phase wrapping
r2phasesel = r2phase(phaseok)
fitab12 = ladfit(r1phasesel,r2phasesel)
;print, fitab
;in printing, try to set position arrays so as to get ~square plots
plot, r1mag, r2mag, psym = 1, xrange = [0,100],yrange = [0,100], xtitle = 'amp rcvr1',$
     ytitle = 'amp rcvr2', position = [0.15,0.55,0.45,0.95]
plot, r1phase, r2phase, psym = 1, xtitle = 'phase, rcvr1', ytitle = 'phase rcvr2',$
     position = [0.55,0.55,0.85,0.95], xrange = [0,360], xstyle = 1, yrange = [0,360],$
        ystyle = 1
oplot, [0,360],[fitab12(0), fitab12(0)+360*fitab12(1)], linestyle = 2, thick = 2

if (nantennas eq 4) then begin
 phaseok = where(abs(r4phase - r3phase) lt 120);90)
 r3phasesel = r3phase(phaseok)		;avoid problems with phase wrapping
 r4phasesel = r4phase(phaseok)
 fitab34 = ladfit(r3phasesel,r4phasesel)
 plot, r3mag, r4mag, psym = 1, xrange = [0,100],yrange = [0,100], xtitle = 'amp rcvr3',$
     ytitle = 'amp rcvr4', position = [0.15,0.15,0.45,0.55]
 plot, r3phase, r4phase, psym = 1, xtitle = 'phase, rcvr3', ytitle = 'phase rcvr4',$
     position = [0.55,0.15,0.85,0.55], xrange = [0,360], xstyle = 1, yrange = [0,360],$
        ystyle = 1
 oplot, [0,360],[fitab34(0), fitab34(0)+360*fitab34(1)], linestyle = 2, thick = 2
;intercept = mean(r4phasesel-r3phasesel)
;oplot, [0,360],[intercept, intercept + 360], linestyle = 2, thick = 2
endif ;nantennas eq 4
;print, 'phase corr EW = ',site.phasecorrectionEW
xyouts,0.1,0.03, 'phase corrections from cadi site program: EW = '+ string(format = '(f6.1)',!radeg*site.phasecorrectionEW)+$
      ' deg, NS = '+ string(format = '(f6.1)',!radeg*site.phasecorrectionNS) + ' deg',/normal

xyouts,0.1,0.05,'linear fit to phases gives phase corrections: EW = '+ string(format = '(f6.1)',-fitab12(0))+' deg,  NS = '$
       + string(format = '(f6.1)', -fitab34(0))+' deg  (see dashed lines)',/normal

exit1receiver:

return
end