;NAME
;    CADI_XYDISTANCE
;
;PURPOSE
;		To plot distance of echoes in e=-w and n-s direction
;   	similar to plt_dist c language program
; CALLING SEQUENCE:
;		CADI_XYDISTANCE, TIMERANGE, CADI_KVEC
;		TIMERANGE = 2 element array from cantime: gives start and endtimes $
;			in seconds (relative to ref time)
;		CADI_KVEC = input structure of type cadi as prepared by cadi_kvec procedure
;		heightrange = 2 element array giving minimum and maximum heights
; KEYWORD PARAMETERS
;		Colour = if set (ne 0) then plot in colour
;
; MODIFICATION HISTORY:
;		written: by JWM April 2004


pro cadi_xydistance, timerange = timerange, cadi_kvec, colour = colour, distance = distance

on_error, 2

h = cadi_kvec.header

;get time information

dt = float(h.dtime)/60
; Get DAYNUM for plot title

; Input date from first file
candate = canmidnight(h.time)    ; Date from time in first file
can_date = h.time
civil_time, year, month, day, daynum, endhour, minute, second, timerange(1)
endday = day
civil_time, year, month, day, daynum, starthour, minute, second, timerange(0)
if (endday gt day) then endhour = endhour + 24

d = cadi_kvec.data
d_x = d.k(0,*)
d_y = d.k(1,*)
d_z = d.k(2,*)
d_h = d.x.h
d_t = d.x.t
d_tf = fltarr(n_elements(d_t))
for i = 0L, n_elements(d_x)-1 do begin
  d_x(i) = 3.0*float(d_h(i))*d_x(i)/d_z(i)
  d_y(i) = 3.0*float(d_h(i))*d_y(i)/d_z(i)
endfor

frequency = h.freqs(d(0).x.f)/1.0e6

if keyword_set(colour) then begin
   !p.multi = [0.1,3]
	!p.background = 255b
	!p.color = 0b
endif else begin
   !p.multi = [0.1,2]
   !p.background = 255b
   !p.color = 0
endelse
erase

 xtitle = 'Hour (UT)'
 reftime = canjan0(timerange(0))
 plot_timerange = timerange - reftime

;stop

if keyword_set(colour) then pos = [0.08,0.55,0.93,0.95] else pos = [0.08,0.55,0.98,0.95]
if not keyword_set(distance) then yaxisrange = [-400,400] else yaxisrange = [-distance,distance]

plot, [0,3],[0,510],/nodata, xrange = plot_timerange, xstyle = 5, charsize = 2.5, $
     yrange = yaxisrange, ystyle = 1, position = pos, xticks = 6, xminor = 2,yminor = 5,$
   title='CADI ' + h.site + ' horizontal distances ' + strcantime(/date,can_date) + $
   '    Day ' + string(daynum, format='(i3)')+ '  frequency = '+ string(frequency, format = '(f5.1)') + ' MHz',$
               ytitle = 'W     distance, km     E'

nooftimes = 3600*(endhour - starthour)/h.dtime
noofhours = endhour - starthour
deltay = float(distance)/200.0
x = [-0.01, 0.01, 0.01, -0.01, -0.01]
x = x*27
y = [-deltay, -deltay, deltay, deltay, -deltay]
y = 0.375*y
usersym, x,y,/fill
speckles = fix(24/noofhours)
timearr = fltarr(nooftimes)
spread = float(distance)/400
for htimex=0L,h.ntimes-1 do begin
  civil_time, year, month, day, daynum, hour, minute, second, h.times(htimex)
plot_time = daynum*24 + hour + float(minute)/60 + float(second)/3600
  timearr(htimex) = plot_time
  sel = where(d.x.t eq htimex,wcount)
  if wcount gt 0 then begin
    dsel = d(sel)
    d_xsel = d_x(sel)
    d_psel = 7*dsel.db
    for c = 0, wcount-1 do begin
    pt = (randomn(seed,speckles)*h.dtime/(3600) + plot_time)*3600 ;+ plot_timerange(0)
    ;print, 'plottime =', plot_time
    py = randomn(seed,speckles)*3*spread + d_xsel(c)
    if keyword_set(colour) then clr = d_psel(c) else clr = !p.color
      oplot, pt, py, psym = 8, color = 255 - clr    ;usersym is psym = 8
    endfor ;c
  endif ;wcount
endfor ;htimex

;put on timesdcale
pticklen = !p.ticklen							;save value of ticklen
!p.ticklen = pticklen / (pos(3) - pos(1))
 !x.charsize = 1.25   ; Compensate CHARSIZE=0.8 in TIMESCALE

 timescale, plot_timerange(0), plot_timerange(1), title=xtitle, charsize = 2, $
      top=top, nolabels=nolabels, tic_factor=-1, nodaylabels=nodaylabels


!p.ticklen = pticklen							;get saved value of ticklen
pos = pos - [0, 0.47, 0, 0.47]
plot, [0,3],[0,510],/nodata, xrange = plot_timerange, xstyle = 5, charsize = 2.5,$
     yrange = yaxisrange, ystyle = 1, position = pos, xticks = 6, xminor = 2,yminor = 5,$
       ytitle = 'S      distance, km     N'


for htimex=0L,h.ntimes-1 do begin
  civil_time, year, month, day, daynum, hour, minute, second, h.times(htimex)
  plot_time = 24*daynum + hour + float(minute)/60 + float(second)/3600
  timearr(htimex) = plot_time
  sel = where(d.x.t eq htimex,wcount)
  if wcount gt 0 then begin
    dsel = d(sel)
    d_ysel = d_y(sel)
    d_psel = 7*dsel.db
    for c = 0, wcount-1 do begin
     if abs(d_ysel(c)) le distance then begin
       pt = (randomn(seed,speckles)*h.dtime/(3600) + plot_time)*3600
       py = randomn(seed,speckles)*3*spread + d_ysel(c)

      if keyword_set(colour) then clr = d_psel(c) else clr = !p.color
     oplot, pt, py, psym = 8, color = 255 - clr;, symsize = 3
      endif
    endfor ;c
  endif ;wcount
endfor ;htimex

timescale, plot_timerange(0), plot_timerange(1), title=xtitle, charsize = 2, $
      top=top, nolabels=nolabels, tic_factor=-1, nodaylabels=nodaylabels

!p.ticklen = pticklen		;restore !p.ticklen

if keyword_set(colour) then begin
  ;put on db scale
    yticklabels = ['0','6','12','18','24','30','36']
    plot, [0,1],[0,1],/nodata, yrange = [0,256], ystyle = 1, xrange = [0,1],charsize = 2,$
     position = [0.97,0.18,0.999,0.85], xstyle = 4, yticks = 6, ytickname = yticklabels, title = 'dB'
    for c = 0,255 do oplot, [0,1],[c,c],color = 255 - c, thick = 3
endif
;stop

return
end