;+
; NAME:
;	IEEE_TO_FLOAT
; PURPOSE:
;	Convert IEEE-standard 4-byte floating point to IDL internal float.
;	IEEE-standard is used by 386/486. This routine will convert a 4-byte
;	floating point number written to disk or tape by DOS to IDL's internal
;	represenation under either DOS or VMS.
; CALLING SEQUENCE:
;	Result = IEEE_TO_FLOAT( BYTES )
; INPUTS:
;	BYTES = 4-element byte vector, representing an IEEE-format floating
;	   point number.
; OUTPUTS:
;	Result = Float scalar.
; RESTRICTIONS:
;	For VMS or WINDOWS.
; PROCEDURE:
;	For WINDOWS, just convert with FLOAT.
;	For VMS, permute the bytes, convert with FLOAT, and multiply by 4.0.
; MODIFICATION HISTORY:
;	Ian Grant, UWO, 12 March 1993: Written for VMS.
;	GRANT, 10 Sep 1993: Modified to work under both DOS and VMS.
;-

function ieee_to_float, bytes

on_error, 2
if howmany( size(bytes) ne size(bytarr(4)) ) gt 1 then $
   message, 'Argument is not a vector of four bytes'

case !version.os of
   'vms': return, 4.0 * float( bytes([2,3,0,1]), 0)
   'windows': return, float(bytes, 0)
   'Win32': return, float(bytes,0)
   else: message, 'routine not implemented for '+!version.os+' operating system'
   endcase
end
