;+
; NAME:
;	ACV
; PURPOSE:
;	Return autocovariance function.
; CALLING SEQUENCE:
;	Result = ACV(X)
; INPUTS:
;	X = vector. Timeseries.
; KEYWORD PARAMETERS:
;	MAXLAG = Number of maximum lag for which acv is returned.
; OUTPUTS:
;	Result = vector of autovariance coefficients for
;		lags 0, 1, ..., MAXLAG. Result(i) is for lag i.
; PROCEDURE:
;	Calls IMSL_CCF with data vector repeated.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 23 Jul 1991: Written in IDL2 by adapting ACF.
;	IFG, 4 Jan 1993: Added ON_ERROR.
;-

function acv, x, maxlag=maxlag

on_error, 2
nobs = n_elements(x)
if nobs lt 1 then message, 'X has too few elements'
if not keyword_set(maxlag) then maxlag = nobs-1
if (maxlag lt 1) or (maxlag ge nobs) then $
   message, 'Must have 1 <= MAXLAG < NOBS'
y = x
iprint = 0
iseopt = 0
imean = 1

imsl_ccf, nobs,x,y,maxlag,iprint,iseopt,imean,xmean,ymean,xvar,ccv1,cc,secc

return, ccv1(maxlag:*)

end
