;+
; NAME:
;	DB
; PURPOSE:
;	Convert to decibels.
; CALLING SEQUENCE:
;	Result = DB(X [,MIN_X=min_x])
; INPUTS:
;	X an array or scalar. In IDL2 a scalar X may be referenced as X(0).
;	   All elements of X must be positive unless MIN_X is provided.
; KEYWORD PARAMETERS:
;	MIN_X = Scalar real. If MIN_X is present and nonzero, then values in X
;	   are clipped from below to MIN_X before conversion to dB.
;	   This avoids errors from non-positive values of X. Default 1e-10.
; OUTPUTS:
;	Result = Same dimensions as X. Values of X clipped and converted to dB
;	   by 10*alog10(x).
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 21 May 1991, IDL2.
;	IFG, 22 Dec 1992: Added ON_ERROR.
;	GRANT, 16 Sep-1993: Changed MIN_X default from 0.1 to 1e-10.
;-

function db, x, min_x=min_x

on_error, 2
if not keyword_set(min_x) then $
   min_x = 1e-10
return, 10.0*alog10(x > min_x)
end
