;+
; NAME:
;	DIFFERENCE
; PURPOSE:
;	Return the differences between successive pairs of elements.
; CALLING SEQUENCE:
;	Result = DIFFERENCE( X )
; INPUTS:
;	X = Input vector of any type on which subtraction is possible.
; OUTPUTS:
;	Result = Vector of same type as X and with one fewer elements.
;	   Result(i) is X(i+1) - X(i).
;	   If X has one element (or none) then Result = 0.
; MODIFICATION HISTORY:
;	Ian Grant, UWO, 24 January 1994: Written.
;-

function difference, x

n = n_elements(x)
if n le 1 then begin
   message, /inform, 'Only zero or one elements in argument'
   return, 0L
   endif
return, x(1:n-1) - x(0:n-2)

end
