;+
; NAME:
;	NONMISSING
; PURPOSE:
;	Return that part of an array which contains nonmissing data.
; CALLING SEQUENCE:
;	RESULT = NONMISSING(X, MAX_VALUE)
; INPUTS:
;	X = input array of data. Missing points have values GE MAX_VALUE.
;	MAX_VALUE = Threshold above which a value is considered missing.
; OUTPUTS:
;	Result = Vector of those values in X which are LT MAX_VALUE, except that
;		if all values in X are missing then a scalar of value MAX_VALUE
;		is returned.
; RESTRICTIONS:
;	Prudence suggests treating the value of the expression
;	(X(i) EQ MAX_VALUE) as indeterminate. So MAX_VALUE should be set to 
;	slightly less than the desired threshold to ensure that all points
;	thought of as missing are in fact rejected.
; PROCEDURE:
;	Uses WHERE.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 22 May 1991, IDL2.
;	IFG,  5 Jan 1993: Added ON_ERROR.
;-

function nonmissing, x, max_value

on_error, 2
w = where(x lt max_value, ngood)
if ngood gt 0 then $
   return, x(w) $
else $
   return, max_value
end
