;+
; NAME:
;	PPOSITION
; PURPOSE:
;	Returns the position vector which PLOT without POSITION would use.
; CALLING SEQUENCE:
;	Result = PPOSITION()
; INPUTS:
;	None.
; OUTPUTS:
;	Result = 4-element float vector [x0,y0,x1,y1] indicating the
;	   Plot Data Window position which would be used if PLOT were called
;	   without the POSITION keyword.
; PROCEDURE:
;	Returns !P.POSITION if defined.
;	Else returned position vector is determined from !P.REGION if defined,
;	else whole device area, using !X/Y.MARGIN and effective !P.CHARSIZE
;	value.
; MODIFICATION HISTORY:
;	Ian Grant, UWO, 16 Sep 1993: Written.
;-

function pposition

; !P.POSITION has precedence, if defined

if !p.position(0) ne !p.position(2) then return, !p.position

; Position is determined from !P.REGION if defined, else whole device area

return, pregion() + $	; !P.REGION if defined, else whole device area
   [1,1,-1,-1] * pcharsize() * $				; In from edges
   [!x.margin(0), !y.margin(0), !x.margin(1), !y.margin(1)] * $ ; Num of chars
   [!d.x_ch_size, !d.y_ch_size, !d.x_ch_size, !d.y_ch_size] / $ ; Device units
   [!d.x_vsize, !d.y_vsize, !d.x_vsize, !d.y_vsize] 		; Device to norm

end
