;+
; NAME:
;	ROUNDUP
; PURPOSE:
;	Round up to a multiple of a given value.
; CALLING SEQUENCE:
;	Result = ROUNDUP( X_IN [,F] )
; INPUTS:
;	X_IN = Integer or real scalar of any sign.
; OPTIONAL INPUT PARAMETERS:
;	F = Factor of which Result is to be a multiple. Default is integer 1.
; OUTPUTS:
;	Result = Scalar of same type as F, containing X_IN rounded up to a 
;	   multiple of F. Rounding is always in positive direction.
; RESTRICTIONS:
;	Only tested for scalars.
; PROCEDURE:
;	Divide X_IN by F, round up to a multiple of 1, multiply by F.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 1990, IDL1.
;	IFG, 29 April 1991: No changes needed for IDL2.
;	IFG, 23 Dec 1992: Added ON_ERROR. Added FLOAT to X_IN/F.
;-

function roundup, x_in,f

on_error, 2
if n_params(0) eq 1 then f=1
x = float(x_in)/f		;%% IFG 23 Dec 1992: Was x_in/f
if x ge 0 then begin
   d = abs(fix(x)) + 1		; d is an integer larger than abs(x)
   y = fix(x-d)+d
   endif $
else $
   y = fix(x)
return, f*y
end
