;+
; NAME:
;	STRIM
; PURPOSE:
;	Convert to a string with no leading or trailing spaces.
;	Calling STRTRIM(NUM,2) is equivalent if default formatting is 
;	accepted. STRIM is maintained because a large number of Ian Grant's
;	routines call it.
; CALLING SEQUENCE:
;	Result = STRIM( NUM [,FORMAT_STRING | ,FORMAT=format_str])
; INPUTS:
;	NUM = Any variable: scalar or vector, numeric or string.
; OPTIONAL INPUTS:
;	FORMAT_STR = Scalar string format specification.
; KEYWORD PARAMETERS:
;	FORMAT = Scalar string format specification.
; OUTPUTS:
;	Result = NUM converted to a string with no leading or trailing spaces.
; PROCEDURE:
;	Returns STRTRIM( STRING( NUM ), 2 ), with optional format in STRING.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 1990, IDL1.
;	IFG, 1991: Converted to IDL2.
;	IFG, 24 Dec 1992: Added ON_ERROR.
;-

function strim, num,format_string, format=fmt

on_error, 2
case n_params() of
   1: if keyword_set(fmt) then $
         return, strtrim(string(num,format=fmt),2) $
      else $
         return, strtrim(string(num),2)
   2: return, strtrim(string(num,format_string),2)
   endcase
end
