;+
; NAME:
;	STRTRM2
; PURPOSE:
;	Trim given character (and spaces) from ends of given string.
; CATEGORY:
;	String functions.
; CALLING SEQUENCE:
;	S2 = STRTRM2(S1,[flag],[chr])
; INPUTS:
;	S1 = String to trim.
; OPTIONAL INPUT PARAMETERS:
;	flag = 0: remove trailing,
;	       1: remove leading,
;	       2: remove both. No flag same as 0.
;	chr = character to trim (def = spaces).
; OUTPUTS:
;	S2 = trimmed string.  Works just like STRTRIM.
; SIDE EFFECTS:
;	Also removes spaces adjacent to trim char.
; PROCEDURE:
;	Uses STRESS to convert chr to spaces and trims with STRTRIM.
; MODIFICATION HISTORY:
;	RES,  JHU-APL,  11 Jan, 1985.
;	Ian Grant, HIA/NRCC, 8 Mar 1991: No changes needed for IDL2.
;	IFG, 4 Jan 1993: Added ON_ERROR.
;-

	FUNCTION STRTRM2,S,FX,CX

	ON_ERROR, 2
	C = ' '
	F = 0
	IF N_PARAMS(0) EQ 3 THEN C = CX
	IF N_PARAMS(0) GE 2 THEN F = FX

	X = STRING([1B])	     ; set up a place saving character.
	S2 = STRTRIM(S,F)	     ; trim spaces.
	S2 = STRESS(S2,'R',0,' ',X)  ; Put a place holder in left over spaces.
	S2 = STRESS(S2,'R',0,C,' ')  ; Turn trim char into spaces.
	S2 = STRTRIM(S2,F)	     ; Trim off ends.
	S2 = STRESS(S2,'R',0,' ',C)  ; Put back whatever trim chars are left.
	S2 = STRESS(S2,'R',0,X,' ')  ; Put back desired spaces.

	RETURN, S2

	END
