;+
; NAME:
;	WITHIN
; PURPOSE:
;	Returns subscripts for elements lying within specified range of values.
; CALLING SEQUENCE:
;	Result = WITHIN(X, RANGE [, COUNT])
; INPUTS:
;	X = Vector.
;	RANGE = 2-element vector. Ends of range against which to compare X.
; OUTPUT:
;	Result = LONG vector. Subscripts to X for which
;	   X(i) GE RANGE(0) AND X(i) LE RANGE(1).
; OPTIONAL OUTPUT PARAMETERS:
;	COUNT = LONG scalar. Number of elements in Result.
; PROCEDURE:
;	Calls WHERE.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 12 June 1992: Written in IDL2.
;	IFG, 4 Jan 1993: Added ON_ERROR.
;-

function within, x, range, count

on_error, 2
if n_params() lt 2 then $
   message, 'Parameters are X, RANGE, COUNT. Must give at least first two.'
return, where( (x ge range(0)) and (x le range(1)) ,count)
end
